#ifndef NT2_DSL_INCLUDE_FUNCTIONS_OPTIMIZE_HPP_INCLUDED
#define NT2_DSL_INCLUDE_FUNCTIONS_OPTIMIZE_HPP_INCLUDED

#include <boost/simd/dsl/functions/optimize.hpp>

#endif
